@@ -21,7 +21,7 @@ class Auth:
         else:
             user["language"] = user.get("language", "ar")
 
-        app = WeDeliverCore.getApp()
+        app = WeDeliverCore.get_app()
         app.logger.debug(user)
         session["user"] = user
 
@@ -37,7 +37,7 @@ class Auth:
 
     @staticmethod
     def get_user_str():
-        # app = WeDeliverCore.getApp()
+        # app = WeDeliverCore.get_app()
         # with app.test_request_context():
         user = Auth.get_user()
 
@@ -52,7 +52,7 @@ class Auth:
 
 
 def verify_user_token(token):
-    app = WeDeliverCore.getApp()
+    app = WeDeliverCore.get_app()
 
     url = "{authenticate_url}".format(
         authenticate_url="{0}/api/v1/authenticate".format(
