@@ -46,3 +46,10 @@ class AppNotFoundError(AppSilentException):
 class AppMissingAuthError(AppSilentException):
     code = 401
     message = "You are unauthenticated"
+
+
+class CustomNotFoundError(AppSilentException):
+    def __init__(self, message):
+        self.message = message
+
+    code = 404
