@@ -43,7 +43,8 @@ def fetch_relational_data(
                 column_name=column_name,
                 compair_operator=compair_operator,
                 column_values="('{}')".format(
-                    "', '".join([str(val) for val in column_values])) if compair_operator == 'IN' else column_values,
+                    "', '".join([str(val) for val in column_values])) if compair_operator == 'IN' else "'{}'".format(
+                    column_values),
             )
             relational_data_result = sql(query)
 
