@@ -21,7 +21,7 @@ def send_critical_error(message, channel=None):
 def send_notification_message(
         message, channel="logs", title="Log", color="#32a4a7", emoji=":dizzy_face:"
 ):
-    app = WeDeliverCore.getApp()
+    app = WeDeliverCore.get_app()
     channel = "eng-{0}-{1}".format(
         app.config.get("FLASK_ENV")
         if app.config.get("FLASK_ENV") == "production"
